@@ -1,7 +1,7 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 use Rope::Object;
 my (%META, %PRO);
 our @ISA;
@@ -442,7 +442,7 @@ Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =cut
 
@@ -520,6 +520,10 @@ If set to a true value then this property value can be updated after initialisat
 
 If set to a true value then the property will be enumerable when you itterate the object for example when you call keys %{$self}. If set to false then the property will be hidden from any itteration. Note also that when itterating your object keys are already ordered based on the order they were assigned.
 
+=head2 private
+
+If set to a true value then the property will be private, If you try to access the property from outside of the object definition then an error will be thrown. (Cannot access Object (Custom) property ($key) as it is private)
+
 =head2 required
 
 If set to a true value then this property is required at initialisation, either by a value key being set or via passing into ->new. I would suggest using this in conjunction with initable when you require a value is passed. If no value is passed and required is set to true then the code will die with a relevant error. (Required property ($key) in object ($object) not set)
