@@ -121,6 +121,10 @@ sub FETCH {
         my ($self, $key) = @_;
         my $k = $self->{properties}->{$key};
 	return undef unless defined $k->{value};
+	my $caller = $self->current_caller;
+	if ($k->{private} && $caller ne $self->{name}) {
+		die "Cannot access Object ($self->{name}) property ($key) as it is private";
+	}
 	if (!$k->{writeable} && !$k->{configurable} && (ref($k->{value}) || '') eq 'CODE') {
 		if ($k->{before} || $k->{after} || $k->{around}) {
 			return sub {
@@ -177,6 +181,15 @@ sub SCALAR {
 
 sub DESTROY { }
 
+sub current_caller {
+	for (qw/0 1 2 3 4 5/) {
+		my $call = scalar caller($_);
+		if ($call !~ m/Rope::(Object|Autoload|Monkey)/) {
+			return $call;
+		}
+	}
+}
+
 1;
 
 __END__ 
